package PERLANCAR::Sort::Sub;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2019-12-15'; # DATE
our $DIST = 'PERLANCAR-Sort-Sub'; # DIST
our $VERSION = '0.07'; # VERSION

1;
# ABSTRACT: PERLANCAR's Sort::Sub subroutines

__END__

=pod

=encoding UTF-8

=head1 NAME

PERLANCAR::Sort::Sub - PERLANCAR's Sort::Sub subroutines

=head1 VERSION

This document describes version 0.07 of PERLANCAR::Sort::Sub (from Perl distribution PERLANCAR-Sort-Sub), released on 2019-12-15.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/PERLANCAR-Sort-Sub>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-PERLANCAR-Sort-Sub>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=PERLANCAR-Sort-Sub>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019, 2017, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
